#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mime-mail
version: 0.4.11
id: mime-mail-0.4.11-d9015aaaa236b99cae24cbb7fe985a3e
key: mimem_GfwvuUO1sCuAzWhs10QE4S
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
homepage: http://github.com/snoyberg/mime-mail
synopsis: Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.
category: Email
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Mail.Mime
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/mime-mail-0.4.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/mime-mail-0.4.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/mime-mail-0.4.11
hs-libraries: HSmime-mail-0.4.11-GfwvuUO1sCuAzWhs10QE4S
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html: /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
